==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.md <==
# AwsRoboMakerDevelopmentEnvironment


```text
aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment
```

```text
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')
```



| Illustration | AwsRoboMakerDevelopmentEnvironment | AwsRoboMakerDevelopmentEnvironmentCard | AwsRoboMakerDevelopmentEnvironmentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.png) | ![illustration for AwsRoboMakerDevelopmentEnvironment](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.Local.png) | ![illustration for AwsRoboMakerDevelopmentEnvironmentCard](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironmentCard.Local.png) | ![illustration for AwsRoboMakerDevelopmentEnvironmentGroup](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironmentGroup.Local.png) |




## AwsRoboMakerDevelopmentEnvironment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironment
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironment('AwsRoboMakerDevelopmentEnvironment', 'Aws Robo Maker Development Environment', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironment
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironment('AwsRoboMakerDevelopmentEnvironment', 'Aws Robo Maker Development Environment', 'an optional tech label')
@enduml
```

## AwsRoboMakerDevelopmentEnvironmentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentCard('AwsRoboMakerDevelopmentEnvironmentCard', 'Aws Robo Maker Development Environment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentCard('AwsRoboMakerDevelopmentEnvironmentCard', 'Aws Robo Maker Development Environment Card', 'an optional description')
@enduml
```

## AwsRoboMakerDevelopmentEnvironmentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentGroup('AwsRoboMakerDevelopmentEnvironmentGroup', 'Aws Robo Maker Development Environment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentGroup('AwsRoboMakerDevelopmentEnvironmentGroup', 'Aws Robo Maker Development Environment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.md <==
# AwsRoboMakerDevelopmentEnvironment


```text
aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment
```

```text
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')
```



| Illustration | AwsRoboMakerDevelopmentEnvironment | AwsRoboMakerDevelopmentEnvironmentCard | AwsRoboMakerDevelopmentEnvironmentGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.png) | ![illustration for AwsRoboMakerDevelopmentEnvironment](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment.Local.png) | ![illustration for AwsRoboMakerDevelopmentEnvironmentCard](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironmentCard.Local.png) | ![illustration for AwsRoboMakerDevelopmentEnvironmentGroup](../../../aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironmentGroup.Local.png) |




## AwsRoboMakerDevelopmentEnvironment

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironment
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironment('AwsRoboMakerDevelopmentEnvironment', 'Aws Robo Maker Development Environment', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironment
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironment('AwsRoboMakerDevelopmentEnvironment', 'Aws Robo Maker Development Environment', 'an optional tech label')
@enduml
```

## AwsRoboMakerDevelopmentEnvironmentCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentCard('AwsRoboMakerDevelopmentEnvironmentCard', 'Aws Robo Maker Development Environment Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentCard
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentCard('AwsRoboMakerDevelopmentEnvironmentCard', 'Aws Robo Maker Development Environment Card', 'an optional description')
@enduml
```

## AwsRoboMakerDevelopmentEnvironmentGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentGroup('AwsRoboMakerDevelopmentEnvironmentGroup', 'Aws Robo Maker Development Environment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsRoboMakerDevelopmentEnvironmentGroup
include('aws-q3-2021/Resource/Robotics/AwsRoboMakerDevelopmentEnvironment')

' renders the element
AwsRoboMakerDevelopmentEnvironmentGroup('AwsRoboMakerDevelopmentEnvironmentGroup', 'Aws Robo Maker Development Environment Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
